@@ -1,9 +1,12 @@
-from logger_local.LoggerComponentEnum import LoggerComponentEnum
 import os
+from dotenv import load_dotenv
+
+from logger_local.LoggerComponentEnum import LoggerComponentEnum
 
 PYTHON_SDK_LOCAL_COMPONENT_ID = 184
 PYTHON_SDK_LOCAL_COMPONENT_NAME = 'python_sdk_local'
 
+load_dotenv()
 ENVIRONMENT_NAME = os.getenv("ENVIRONMENT_NAME")
 BRAND_NAME = os.getenv("BRAND_NAME")
 LOGZIO_TOKEN = os.getenv("LOGZIO_TOKEN")
