@@ -1,26 +1,26 @@
-import sys
-import os
-from urllib.parse import urlparse
 import json
+import os
+from datetime import date, datetime, time, timedelta
+from urllib.parse import urlparse
+
 from dotenv import load_dotenv
-from datetime import time, datetime, timedelta, date
-script_directory = os.path.dirname(os.path.abspath(__file__))
-sys.path.append(os.path.join(script_directory, '..'))
+from logger_local.Logger import Logger
 
-from .constants import OBJECT_TO_INSERT_CODE, BRAND_NAME, ENVIRONMENT_NAME  # noqa: E402
-from .validate import validate_environment_name, validate_brand_name  # noqa: E402
-load_dotenv()
-from logger_local.Logger import Logger  # noqa: E402
+from .constants import (BRAND_NAME, ENVIRONMENT_NAME,  # noqa: E402
+                        OBJECT_TO_INSERT_CODE)
+from .validate_environment import validate_brand_name  # noqa: E402
+from .validate_environment import validate_environment_name
 
+load_dotenv()  # for our_get_env
 logger = Logger.create_logger(object=OBJECT_TO_INSERT_CODE)
 
 
-def timedelta_to_time_format(timedelta: timedelta) -> str:
+def timedelta_to_time_format(time_delta: timedelta) -> str:
     """
     Convert a timedelta to a time format in HH:MM:SS.
 
     Parameters:
-        timedelta (datetime.timedelta): The timedelta to be converted.
+        time_delta (datetime.timedelta): The timedelta to be converted.
 
     Returns:
         str: A string in HH:MM:SS format representing the time duration.
@@ -35,11 +35,10 @@ def timedelta_to_time_format(timedelta: timedelta) -> str:
         '02:30:45'
     """
     TIMEDELTA_TO_TIME_FORMAT_METHOD_NAME = "timedelta_to_time_format"
-    logger.start(TIMEDELTA_TO_TIME_FORMAT_METHOD_NAME,
-                 object={'timedelta': timedelta.__str__()})
+    logger.start(TIMEDELTA_TO_TIME_FORMAT_METHOD_NAME, object={'time_delta': time_delta})
 
     # Calculate the total seconds and convert to HH:MM:SS format
-    total_seconds = int(timedelta.total_seconds())
+    total_seconds = int(time_delta.total_seconds())
     hours = total_seconds // 3600
     minutes = (total_seconds % 3600) // 60
     seconds = total_seconds % 60
@@ -58,7 +57,7 @@ def is_valid_time_range(time_range: tuple) -> bool:
     """
     IS_VALID_TIME_RANGE_METHOD_NAME = "is_valid_time_range"
     logger.start(IS_VALID_TIME_RANGE_METHOD_NAME, object={
-                 "time_range": time_range.__str__()})
+        "time_range": time_range.__str__()})
     if len(time_range) != 2:
         logger.end(IS_VALID_TIME_RANGE_METHOD_NAME, object={
             "is_valid_time_range_result": False, "reason": "len(time_range) != 2"})
@@ -76,7 +75,7 @@ def is_valid_time_range(time_range: tuple) -> bool:
             return False
 
     logger.end(IS_VALID_TIME_RANGE_METHOD_NAME, object={
-               "is_valid_time_range_result": True})
+        "is_valid_time_range_result": True})
     return True
 
 
@@ -93,10 +92,10 @@ def is_valid_date_range(date_range: tuple) -> bool:
     """
     IS_VALID_DATE_RANGE_METHOD_NAME = "is_valid_date_range"
     logger.start(IS_VALID_DATE_RANGE_METHOD_NAME, object={
-                 "date_range": date_range.__str__()})
+        "date_range": date_range.__str__()})
     if len(date_range) != 2:
         logger.end(IS_VALID_DATE_RANGE_METHOD_NAME, object={
-                   "is_valid_date_range_result": False, "reason": "len(date_range) != 2"})
+            "is_valid_date_range_result": False, "reason": "len(date_range) != 2"})
         return False
 
     for date_obj in date_range:
@@ -105,7 +104,7 @@ def is_valid_date_range(date_range: tuple) -> bool:
                 "is_valid_date_range_result": False, "reason": "date_range contains non-date objects"})
             return False
     logger.end(IS_VALID_DATE_RANGE_METHOD_NAME, object={
-               "is_valid_date_range_result": True})
+        "is_valid_date_range_result": True})
     return True
 
 
@@ -115,10 +114,10 @@ def is_valid_datetime_range(datetime_range: tuple) -> bool:
     """
     IS_VALID_DATETIME_RANGE_METHOD_NAME = "is_valid_datetime_range"
     logger.start(IS_VALID_DATETIME_RANGE_METHOD_NAME, object={
-                 "datetime_range": datetime_range.__str__()})
+        "datetime_range": datetime_range.__str__()})
     if len(datetime_range) != 2:
         logger.end(IS_VALID_DATETIME_RANGE_METHOD_NAME, object={
-                   "is_valid_datetime_range_result": False, "reason": "len(datetime_range) != 2"})
+            "is_valid_datetime_range_result": False, "reason": "len(datetime_range) != 2"})
         return False
 
     for datetime_obj in datetime_range:
@@ -127,7 +126,7 @@ def is_valid_datetime_range(datetime_range: tuple) -> bool:
                 "is_valid_datetime_range_result": False, "reason": "datetime_range contains non-datetime objects"})
             return False
     logger.end(IS_VALID_DATETIME_RANGE_METHOD_NAME, object={
-               "is_valid_datetime_range_result": True})
+        "is_valid_datetime_range_result": True})
     return True
 
 
@@ -160,17 +159,17 @@ def is_list_of_dicts(obj):
         if not isinstance(obj, list):
             is_list_of_dicts_result = False
             logger.end(IS_LIST_OF_DICTS_FUNCTION_NAME, object={
-                       "is_list_of_dicts_result": is_list_of_dicts_result})
+                "is_list_of_dicts_result": is_list_of_dicts_result})
             return is_list_of_dicts_result
         for item in obj:
             if not isinstance(item, dict):
                 is_list_of_dicts_result = False
                 logger.end(IS_LIST_OF_DICTS_FUNCTION_NAME, object={
-                           "is_list_of_dicts_result": is_list_of_dicts_result})
+                    "is_list_of_dicts_result": is_list_of_dicts_result})
                 return is_list_of_dicts_result
         is_list_of_dicts_result = True
         logger.end(IS_LIST_OF_DICTS_FUNCTION_NAME, object={
-                   "is_list_of_dicts_result": is_list_of_dicts_result})
+            "is_list_of_dicts_result": is_list_of_dicts_result})
         return is_list_of_dicts_result
     except Exception as e:
         logger.end(IS_LIST_OF_DICTS_FUNCTION_NAME, exception=e)
@@ -190,14 +189,14 @@ def is_time_in_time_range(check_time: time, time_range: tuple) -> bool:
     """
     IS_TIME_IN_TIME_RANGE_METHOD_NAME = "is_time_in_time_range"
     logger.start(IS_TIME_IN_TIME_RANGE_METHOD_NAME, object={
-                 "check_time": check_time.__str__(), "time_range": time_range.__str__()})
+        "check_time": check_time.__str__(), "time_range": time_range.__str__()})
     if not is_valid_time_range(time_range) or not isinstance(check_time, time):
         logger.end(IS_TIME_IN_TIME_RANGE_METHOD_NAME, object={
-                   "is_time_in_time_range_result": False})
+            "is_time_in_time_range_result": False})
         return False
     start_time, end_time = time_range
     logger.end(IS_TIME_IN_TIME_RANGE_METHOD_NAME, object={
-               "is_time_in_time_range_result": start_time <= check_time <= end_time})
+        "is_time_in_time_range_result": start_time <= check_time <= end_time})
     return start_time <= check_time <= end_time
 
 
@@ -214,15 +213,15 @@ def is_date_in_date_range(check_date: date, date_range: tuple) -> bool:
     """
     IS_DATE_IN_DATE_RANGE_METHOD_NAME = "is_date_in_date_range"
     logger.start(IS_DATE_IN_DATE_RANGE_METHOD_NAME, object={
-                 "check_date": check_date.__str__(), "date_range": date_range.__str__()})
+        "check_date": check_date.__str__(), "date_range": date_range.__str__()})
     if not is_valid_date_range(date_range) or not isinstance(check_date, date):
         logger.end(IS_DATE_IN_DATE_RANGE_METHOD_NAME, object={
-                   "is_date_in_date_range_result": False})
+            "is_date_in_date_range_result": False})
         return False
 
     start_date, end_date = date_range
     logger.end(IS_DATE_IN_DATE_RANGE_METHOD_NAME, object={
-               "is_date_in_date_range_result": start_date <= check_date <= end_date})
+        "is_date_in_date_range_result": start_date <= check_date <= end_date})
     return start_date <= check_date <= end_date
 
 
@@ -241,13 +240,13 @@ def is_datetime_in_datetime_range(check_datetime: datetime, datetime_range: tupl
     logger.start(IS_DATETIME_IN_DATETIME_RANGE_METHOD_NAME)
     if not is_valid_datetime_range(datetime_range) or not isinstance(check_datetime, datetime):
         logger.end(IS_DATETIME_IN_DATETIME_RANGE_METHOD_NAME, object={
-                   "is_valid_datetime_range": False})
+            "is_valid_datetime_range": False})
         return False
 
     start_datetime, end_datetime = datetime_range
     is_datetime_in_datetime_range_result = start_datetime <= check_datetime <= end_datetime
     logger.end(IS_DATETIME_IN_DATETIME_RANGE_METHOD_NAME, object={
-               "is_datetime_in_datetime_range_result": is_datetime_in_datetime_range_result})
+        "is_datetime_in_datetime_range_result": is_datetime_in_datetime_range_result})
     return is_datetime_in_datetime_range_result
 
 
@@ -266,9 +265,9 @@ def create_authorization_http_headers(user_jwt: str):
 
 def create_return_http_headers():
     return {
-                "Content-Type": "application/json",
-                "Access-Control-Allow-Origin": "*",
-            }
+        "Content-Type": "application/json",
+        "Access-Control-Allow-Origin": "*",
+    }
 
 
 # https://google.github.io/styleguide/jsoncstyleguide.xml?showone=Property_Name_Format#Property_Name_Format
@@ -286,3 +285,19 @@ def get_brand_name():
 def get_environment_name():
     validate_environment_name()
     return ENVIRONMENT_NAME
+
+
+def our_get_env(key: str) -> str:
+    return os.getenv(key)
+
+
+def get_sql_hostname():
+    return our_get_env("RDS_HOSTNAME")
+
+
+def get_sql_username():
+    return our_get_env("RDS_USERNAME")
+
+
+def get_sql_password():
+    return our_get_env("RDS_PASSWORD")
